MessagePayload

Struct MessagePayload 

pub struct MessagePayload {
Show 15 fields pub header: Option<Header>, pub topic: String, pub message: Option<String>, pub title: Option<String>, pub tags: Vec<String>, pub priority: Option<i32>, pub actions: Vec<Action>, pub click: Option<String>, pub attach: Option<String>, pub markdown: Option<bool>, pub icon: Option<String>, pub filename: Option<String>, pub delay: Option<String>, pub email: Option<String>, pub call: Option<String>,
}

Fields

header: Option<Header>topic: String

Required: Target topic name

message: Option<String>

Message body; set to triggered if empty or not passed

title: Option<String>

Message title

tags: Vec<String>

List of tags that may or may not map to emojis

priority: Option<i32>

Message priority

actions: Vec<Action>

Custom user action buttons for notifications

click: Option<String>

Website opened when notification is clicked

attach: Option<String>

URL of an attachment

markdown: Option<bool>

Set to true if the message is Markdown-formatted

icon: Option<String>

URL to use as notification icon

filename: Option<String>

File name of the attachment

delay: Option<String>

Timestamp or duration for delayed delivery

email: Option<String>

E-mail address for e-mail notifications

call: Option<String>

Phone number to use for voice call (or “yes”)

Implementations

Source

impl MessagePayload

pub fn message(&self) -> &str

Returns the value of message, or the default value if message is unset.

pub fn title(&self) -> &str

Returns the value of title, or the default value if title is unset.

pub fn priority(&self) -> Priority

Returns the enum value of priority, or the default if the field is unset or set to an invalid enum value.

pub fn set_priority(&mut self, value: Priority)

Sets priority to the provided enum value.

pub fn click(&self) -> &str

Returns the value of click, or the default value if click is unset.

pub fn attach(&self) -> &str

Returns the value of attach, or the default value if attach is unset.

pub fn markdown(&self) -> bool

Returns the value of markdown, or the default value if markdown is unset.

pub fn icon(&self) -> &str

Returns the value of icon, or the default value if icon is unset.

pub fn filename(&self) -> &str

Returns the value of filename, or the default value if filename is unset.

pub fn delay(&self) -> &str

Returns the value of delay, or the default value if delay is unset.

pub fn email(&self) -> &str

Returns the value of email, or the default value if email is unset.

pub fn call(&self) -> &str

Returns the value of call, or the default value if call is unset.